<?php defined('C5_EXECUTE') or die("Access Denied.");

/**
 * Nav Menu package for Concrete5
 * Copyright 2020, Alex Borisov. All Rights Reserved.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @author Alex Borisov <linuxoidoz@gmail.com>
 * @copyright 2018-2020, Alex Borisov. All Rights Reserved.
 * @package Concrete\Package\ab_nav_menu
 */

use Concrete\Core\Support\Facade\Url;

?>

<div class="ab-nav-menu">
    <?php
    if ($pages) {
        switch ($menu_style) {
            case 0:
                $style = 'links';
                $tag_open = '<ul>';
                $tag_close = '</ul>';
                break;
            case 1:
                $style = 'breadcrumbs';
                $tag_open = '<ol class="breadcrumb">';
                $tag_close = '</ol>';
                break;
            case 2:
                $style = 'tabs';
                $tag_open = '<ul class="nav nav-tabs">';
                $tag_close = '</ul>';
                break;
            case 3:
                $style = 'pills';
                $tag_open = '<ul class="nav nav-pills">';
                $tag_close = '</ul>';
                break;
            case 4:
                $style = 'stacked';
                $tag_open = '<ul class="nav nav-pills nav-stacked">';
                $tag_close = '</ul>';
                break;
            case 5:
                $style = 'sidebar';
                $tag_open = '<ul>';
                $tag_close = '</ul>';
                break;
        }
        ?>
        <div class="ab-nav-menu-<?php echo $style; ?>">
            <?php
            echo $tag_open;
                if ($include_home) {
                    $home_name = t($home->getCollectionName());
                    $home_path = $home->getCollectionPath();
                    
                    if ($home->getCollectionID() == $page_id) {
                    ?>
                        <li class="active"><a href="<?php echo Url::to('/', $home_path); ?>"><?php echo $home_name; ?></a></li>
                    <?php } else { ?>
                        <li><a href="<?php echo Url::to('/', $home_path); ?>"><?php echo $home_name; ?></a></li>
                    <?php
                    }
                }
                
                foreach ($pages as $p) {
                    $page = $p[0];
                    $page_name = t($page->getCollectionName());
                    
                    if ($page->isExternalLink()) {
                        $page_path = $page->getCollectionLink();
                        ?>
                        <li><a href="<?php echo $page_path; ?>"><?php echo $page_name; ?></a>
                    <?php
                    }
                    else {
                        $page_path = $page->getCollectionPath();
                        
                        if ($parent_no_go) { ?>
                            <li><a class="no-go"><?php echo $page_name; ?></a>
                        <?php } elseif ($page->getCollectionID() == $page_id) { ?>
                            <li class="active"><a href="<?php echo Url::to('/', $page_path); ?>"><?php echo $page_name; ?></a>
                        <?php } else { ?>
                            <li><a href="<?php echo Url::to('/', $page_path); ?>"><?php echo $page_name; ?></a>
                            <?php }
                            if ($show_children) {
                                $children = $p[1];
                                if (!empty($children)) { ?>
                                    <ul class="children">
                                    <?php
                                    foreach ($children as $child) {
                                        $child_name = t($child->getCollectionName());
                                        $child_path = $child->getCollectionPath();
                                        if ($child->getCollectionID() == $page_id) {
                                        ?>
                                            <li class="active"><a href="<?php echo Url::to('/', $child_path); ?>"><?php echo $child_name; ?></a></li>
                                        <?php } else { ?>
                                            <li><a href="<?php echo Url::to('/', $child_path); ?>"><?php echo $child_name; ?></a></li>
                                        <?php }
                                    }
                                    ?>
                                    </ul>
                                <?php
                                }
                            }
                            ?>
                            </li>
                    <?php
                    }
                }
            echo $tag_close;
            ?>
        </div>
    <?php } ?>
</div>
